function [scores, auc] = getRFresults(trainingDataFilename, trainingLabelsFilename, testDataFilename, testLabelsFilename, numTrees)
%This function trains a Random Forest classfier given a training data set 
%and then predicts on a test set.
%
% Sample run: 
% getRFresults('bioplex_MM_features_training_spoke_model', 'bioplex_training_labels_spoke_model', 'bioplex_MM_features_test_spoke_model', 'bioplex_test_labels_spoke_model', 50)

    if (nargin < 5)
        numTrees = 100;
    end
    
    filenameData = [trainingDataFilename, '.tsv'];
    X = load(filenameData);
    filenameLabels = [trainingLabelsFilename, '.tsv'];
    Y = load(filenameLabels);
    numPos = length(find(Y > 0));
    numNeg = length(Y) - numPos;
    ratio = numNeg/numPos;
%    priorPos = numPos/(numPos+numNeg);
%    priorNeg = 1.0 - priorPos;
    C = [0, 1; ratio, 0];
    b = TreeBagger(numTrees, X, Y, 'cost', C, 'OOBVarImp', 'On', 'OOBPrediction', 'On', 'OOBPredictorImportance', 'On', 'Method', 'Classification');
%    b = TreeBagger(numTrees, X, Y, 'OOBVarImp', 'On', 'OOBPrediction', 'On', 'OOBPredictorImportance', 'On', 'Method', 'Classification');
    [TrLabel, TrScores] = oobPredict(b); 
    filenameData = [trainingDataFilename, '_predictions_rf_', num2str(numTrees), '.txt'];
    dlmwrite(filenameData, TrScores(:, end));

    filenameData = [testDataFilename, '.tsv'];
    Xt = load(filenameData);
    filenameLabels = [testLabelsFilename, '.tsv'];
    Yt = load(filenameLabels);
    [label, scores] = predict(b, Xt);
    
    filenameData = [testDataFilename, '_predictions_rf_', num2str(numTrees), '.txt'];
    dlmwrite(filenameData, scores(:, end));
%    auc = get_auc_ultra(scores(:,2), Yt);
end

